# List of the things to do before next release

- [X] Detect includes in flex and bison files
- [X] Implement a display of the percent of the compilation elapsed.
- [X] Improve the display on multithreading (get the output in a buffer and add a mutex for the display of this output)
- [ ] ~~Remove the display of the file name when compiling with MSVC~~ *WONTFIX*